pt-br:

uma biblioteca não oficial da squarecloud api

> [https://docs.squarecloud.app/api/introducao]()


en:

an unofficial squarecloud library api

> [https://docs.squarecloud.app/api/introducao]()
